pm4py.algo.discovery.alpha.data\_structures package
===================================================

Submodules
----------

pm4py.algo.discovery.alpha.data\_structures.alpha\_classic\_abstraction module
------------------------------------------------------------------------------

.. automodule:: pm4py.algo.discovery.alpha.data_structures.alpha_classic_abstraction
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pm4py.algo.discovery.alpha.data_structures
   :members:
   :undoc-members:
   :show-inheritance:
